import { PDFViewer } from "pdfjs-dist/types/web/pdf_viewer";
import React, { ReactElement } from "react";
import { GhostHighlight, Highlight, HighlightBindings } from "../types";
interface HighlightLayerProps {
    highlightsByPage: {
        [pageNumber: number]: Array<Highlight | GhostHighlight>;
    };
    /** The page number of the PDF document to highlight (1 indexed). */
    pageNumber: number;
    /** ID of the highlight the parent PDF Highlighter is trying to autoscroll to. */
    scrolledToHighlightId?: string | null;
    viewer: PDFViewer;
    /** Whether there is currently a mouse selection or text selection in the same pdf viewer  */
    isSelectionInProgress: () => boolean;
    /**
     * Group of DOM refs for all the highlights on this layer.
     * See the type comment for more explanation.
     */
    highlightBindings: HighlightBindings;
    /**
     * This should be a HighlightContainer of some sorts. It will be given
     * appropriate context for a single highlight which it can then use to
     * render a TextHighlight, AreaHighlight, etc. in the correct place.
     */
    children: ReactElement;
}
/**
 * An internal component that holds all the highlights and ghost highlights
 * for a single page of a PDF document.
 * It should be given a HighlightContainer as a child and all children will be wrapped
 * in the correct HighlightContext. Its rendering should be managed by the PdfHighlighter.
 */
declare const HighlightLayer: ({ highlightsByPage, pageNumber, scrolledToHighlightId, viewer, isSelectionInProgress, highlightBindings, children, }: HighlightLayerProps) => React.JSX.Element;
export default HighlightLayer;
