"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const HighlightContext_1 = require("../contexts/HighlightContext");
const coordinates_1 = require("../lib/coordinates");
const screenshot_1 = __importDefault(require("../lib/screenshot"));
const EMPTY_ID = "empty-id";
/**
 * An internal component that holds all the highlights and ghost highlights
 * for a single page of a PDF document.
 * It should be given a HighlightContainer as a child and all children will be wrapped
 * in the correct HighlightContext. Its rendering should be managed by the PdfHighlighter.
 */
const HighlightLayer = ({ highlightsByPage, pageNumber, scrolledToHighlightId, viewer, isSelectionInProgress, highlightBindings, children, }) => {
    const currentHighlights = highlightsByPage[pageNumber] || [];
    return (react_1.default.createElement("div", null, currentHighlights.map((highlight, index) => {
        const viewportHighlight = {
            ...highlight,
            id: "id" in highlight ? highlight.id : EMPTY_ID, // Give Empty ID to GhostHighlight
            comment: "comment" in highlight ? highlight.comment : { text: "" }, // Give empty comment to GhostHighlight
            position: (0, coordinates_1.scaledPositionToViewport)(highlight.position, viewer),
        };
        const isScrolledTo = Boolean(scrolledToHighlightId === viewportHighlight.id);
        const highlightUtils = {
            highlight: viewportHighlight,
            key: index,
            isSelectionInProgress,
            viewportToScaled: (rect) => {
                const viewport = viewer.getPageView((rect.pageNumber || pageNumber) - 1 // Convert to 0 index
                ).viewport;
                return (0, coordinates_1.viewportToScaled)(rect, viewport);
            },
            screenshot: (boundingRect) => (0, screenshot_1.default)(boundingRect, pageNumber, viewer),
            isScrolledTo: isScrolledTo,
            highlightBindings,
        };
        return (react_1.default.createElement(HighlightContext_1.HighlightContext.Provider, { value: highlightUtils, key: index }, children));
    })));
};
exports.default = HighlightLayer;
//# sourceMappingURL=HighlightLayer.js.map