import React, { ReactElement } from "react";
interface MonitoredHighlightContainerProps {
    /**
     * A callback function to execute when the mouse hovers over the children/highlight.
     * Can be used for triggering popup renders.
     *
     * @param monitoredPopupContent - The content to display in a popup.
     */
    onMouseOver: (monitoredPopupContent: ReactElement) => void;
    /**
     * The content to display in a popup. NOTE: This will not render the popupContent,
     * but it will monitor mouse activity over it
     */
    popupContent: ReactElement;
    /**
     * A callback function to execute when the mouse completely moves out from both the popupContent
     * and highlight (children).
     */
    onMouseOut: () => void;
    /**
     * Container children. Ideally, should be highlight components of some sort.
     */
    children: ReactElement;
}
/**
 * A container for a highlight component that monitors whether a mouse is over a highlight
 * and over some secondary/popup content. This does not render any popup/tip,
 * but it should ideally be used to set the visible state / rendering of a popup.
 */
declare const MonitoredHighlightContainer: ({ onMouseOver, popupContent, onMouseOut, children, }: MonitoredHighlightContainerProps) => React.JSX.Element;
export default MonitoredHighlightContainer;
