import React, { CSSProperties } from "react";
import "../style/MouseSelection.css";
import type { LTWH } from "../types.js";
interface MouseSelectionProps {
    /**
     * Callback function for when the user stops dragging their mouse
     * and a valid area selection is made. In general, this will only
     * be called if a mouse selection is even rendered.
     *
     * @param startTarget - Whatever element the user's pointer started selection on.
     * @param boundingRect - The bounding rectangle of the mouse selection.
     * @param resetSelection - Callback to reset current selection.
     */
    onSelection: (startTarget: HTMLElement, boundingRect: LTWH, resetSelection: () => void) => void;
    onDragStart: () => void;
    /**
     * Callback whenever a mouse selection ends. This will be called
     * whenever a selection resets and thus even when the selection is
     * invalid/not rendered. This should be used for handling selection
     * interference with the parent component (e.g., disabling text selection).
     */
    onDragEnd: () => void;
    shouldStart: (event: MouseEvent) => boolean;
    /**
     * Callback whenever the mouse selection area changes.
     *
     * @param isVisible - Whether the mouse selection is rendered (i.e., non-zero area)
     */
    onChange: (isVisible: boolean) => void;
    style?: CSSProperties;
}
/**
 * A component that enables the creation of rectangular and interactive
 * mouse selections within a given container. NOTE: This does not disable
 * selection in whatever container the component is placed in. That must be handled
 * through the onDragStart and onDragEnd events.
 */
declare const MouseSelection: ({ onSelection, onDragStart, onDragEnd, shouldStart, onChange, style, }: MouseSelectionProps) => React.JSX.Element;
export default MouseSelection;
