"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const pdfjs_dom_1 = require("../lib/pdfjs-dom");
require("../style/MouseSelection.css");
const getBoundingRect = (start, end) => {
    return {
        left: Math.min(end.x, start.x),
        top: Math.min(end.y, start.y),
        width: Math.abs(end.x - start.x),
        height: Math.abs(end.y - start.y),
    };
};
// It's impossible to screenshot or open a context menu on a rect with 0 area
// So we need to prevent their render.
const shouldRender = (boundingRect) => {
    return boundingRect.width >= 1 && boundingRect.height >= 1;
};
/**
 * A component that enables the creation of rectangular and interactive
 * mouse selections within a given container. NOTE: This does not disable
 * selection in whatever container the component is placed in. That must be handled
 * through the onDragStart and onDragEnd events.
 */
const MouseSelection = ({ onSelection, onDragStart, onDragEnd, shouldStart, onChange, style, }) => {
    const [start, setStart] = (0, react_1.useState)(null);
    const [end, setEnd] = (0, react_1.useState)(null);
    const [locked, setLocked] = (0, react_1.useState)(false);
    const rootRef = (0, react_1.useRef)(null);
    // Needed in order to grab the page info of a mouse selection
    const startTargetRef = (0, react_1.useRef)(null);
    const reset = () => {
        // onDragEnd(); Not sure why this was ever here??
        setStart(null);
        setEnd(null);
        setLocked(false);
    };
    (0, react_1.useEffect)(() => {
        const isVisible = Boolean(start && end);
        onChange(isVisible);
    }, [start, end]);
    (0, react_1.useEffect)(() => {
        if (!rootRef.current)
            return;
        const container = (0, pdfjs_dom_1.asElement)(rootRef.current.parentElement);
        let containerBoundingRect = null;
        const containerCoords = (pageX, pageY) => {
            containerBoundingRect ||= container.getBoundingClientRect();
            return {
                x: pageX - containerBoundingRect.left + container.scrollLeft,
                y: pageY -
                    containerBoundingRect.top +
                    container.scrollTop -
                    window.scrollY,
            };
        };
        const handleMouseMove = (event) => {
            if (!start || locked)
                return;
            setEnd(containerCoords(event.pageX, event.pageY));
        };
        const handleMouseDown = (event) => {
            if (!shouldStart(event)) {
                reset();
                return;
            }
            startTargetRef.current = (0, pdfjs_dom_1.asElement)(event.target);
            onDragStart();
            setStart(containerCoords(event.pageX, event.pageY));
            setEnd(null);
            setLocked(false);
        };
        const handleMouseUp = (event) => {
            if (!start)
                return;
            const newEnd = containerCoords(event.pageX, event.pageY);
            const boundingRect = getBoundingRect(start, newEnd);
            if (!container.contains((0, pdfjs_dom_1.asElement)(event.target)) ||
                !shouldRender(boundingRect)) {
                reset();
                return;
            }
            setEnd(newEnd);
            setLocked(true);
            if (start && end && startTargetRef.current) {
                onSelection(startTargetRef.current, boundingRect, reset);
                onDragEnd();
            }
        };
        container.addEventListener("mousemove", handleMouseMove);
        container.addEventListener("mousedown", handleMouseDown);
        const { ownerDocument: doc } = container;
        if (doc.body)
            doc.body.addEventListener("mouseup", handleMouseUp);
        return () => {
            container.removeEventListener("mousemove", handleMouseMove);
            container.removeEventListener("mousedown", handleMouseDown);
            doc.body.removeEventListener("mouseup", handleMouseUp);
        };
    }, [start, end]);
    return (react_1.default.createElement("div", { className: "MouseSelection-container", ref: rootRef }, start && end && (react_1.default.createElement("div", { className: "MouseSelection", style: { ...getBoundingRect(start, end), ...style } }))));
};
exports.default = MouseSelection;
//# sourceMappingURL=MouseSelection.js.map