"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const coordinates_1 = require("../lib/coordinates");
const pdfjs_dom_1 = require("../lib/pdfjs-dom");
const screenshot_1 = __importDefault(require("../lib/screenshot"));
const MouseSelection_1 = __importDefault(require("./MouseSelection"));
const disable_text_selection_1 = require("../lib/disable-text-selection");
/**
 * A helper component that defines and processes the right props to setup a MouseSelection
 * component inside of a PdfHighlighter component. Its existence is highly dependent on a
 * PdfHighlighter, but it is independently written to help declutter the PdfHighlighter.
 */
const MouseSelectionRenderer = ({ viewer, onChange, onAfterSelection, enableAreaSelection, style, }) => {
    const handleSelection = (startTarget, boundingRect, resetSelection) => {
        const page = (0, pdfjs_dom_1.getPageFromElement)(startTarget);
        if (!page)
            return;
        const pageBoundingRect = {
            ...boundingRect,
            top: boundingRect.top - page.node.offsetTop,
            left: boundingRect.left - page.node.offsetLeft,
            pageNumber: page.number,
        };
        const viewportPosition = {
            boundingRect: pageBoundingRect,
            rects: [],
        };
        const scaledPosition = (0, coordinates_1.viewportPositionToScaled)(viewportPosition, viewer);
        const image = (0, screenshot_1.default)(pageBoundingRect, pageBoundingRect.pageNumber, viewer);
        onAfterSelection(viewportPosition, scaledPosition, image, resetSelection);
    };
    return (react_1.default.createElement(MouseSelection_1.default, { onDragStart: () => (0, disable_text_selection_1.disableTextSelection)(viewer, true), onDragEnd: () => (0, disable_text_selection_1.disableTextSelection)(viewer, false), onChange: onChange, shouldStart: (event) => enableAreaSelection(event) &&
            (0, pdfjs_dom_1.isHTMLElement)(event.target) &&
            Boolean((0, pdfjs_dom_1.asElement)(event.target).closest(".page")), onSelection: handleSelection, style: style }));
};
exports.default = MouseSelectionRenderer;
//# sourceMappingURL=MouseSelectionRenderer.js.map