"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("pdfjs-dist/web/pdf_viewer.css");
require("../style/PdfHighlighter.css");
require("../style/pdf_viewer.css");
const lodash_debounce_1 = __importDefault(require("lodash.debounce"));
const pdf_viewer_1 = require("pdfjs-dist/legacy/web/pdf_viewer");
const react_1 = __importStar(require("react"));
const client_1 = require("react-dom/client");
const PdfLoaderContext_1 = require("../contexts/PdfLoaderContext");
const SelectionContext_1 = require("../contexts/SelectionContext");
const TipContext_1 = require("../contexts/TipContext");
const coordinates_1 = require("../lib/coordinates");
const disable_text_selection_1 = require("../lib/disable-text-selection");
const get_bounding_rect_1 = __importDefault(require("../lib/get-bounding-rect"));
const get_client_rects_1 = __importDefault(require("../lib/get-client-rects"));
const group_highlights_by_page_1 = __importDefault(require("../lib/group-highlights-by-page"));
const pdfjs_dom_1 = require("../lib/pdfjs-dom");
const HighlightLayer_1 = __importDefault(require("./HighlightLayer"));
const MouseSelectionRenderer_1 = __importDefault(require("./MouseSelectionRenderer"));
const TipRenderer_1 = __importDefault(require("./TipRenderer"));
const SCROLL_MARGIN = 10;
const TIP_WAIT = 250; // Debounce wait time in milliseconds for a selection changing and a tip being displayed
const DEFAULT_SCALE_VALUE = "auto";
const DEFAULT_TEXT_SELECTION_COLOR = "rgba(153,193,218,255)";
/**
 * This is a large-scale PDF viewer component designed to facilitate highlighting.
 * It should be used as a child to a PdfLoader to ensure proper document loading.
 * This does not handle rendering of highlights, but it can provide a HighlightContext
 * to a HighlightRenderer for each highlight per page per document with capabilities
 * to generate tips. However, this does handle text selection and (optionally) area selection.
 */
const PdfHighlighter = ({ highlights, onScrollAway, scrollRef, tipViewerUtilsRef, pdfViewerRef, pdfScaleValue = DEFAULT_SCALE_VALUE, onSelectionFinished, selectionTip, enableAreaSelection, mouseSelectionStyle, children, textSelectionColor = DEFAULT_TEXT_SELECTION_COLOR, style, }) => {
    const containerNodeRef = (0, react_1.useRef)(null);
    const pdfDocument = (0, PdfLoaderContext_1.usePdfDocument)();
    // These are all refs because
    // 1. We need to use their updated states immediately
    // 2. HighlightLayers are manually rendered per page and thus unaffected by state
    const highlightBindingsRef = (0, react_1.useRef)({}); // Reference to highlight bindings per page
    const ghostHighlightRef = (0, react_1.useRef)(null); // Reference to in-progress/temporary highlight
    const textSelectionRef = (0, react_1.useRef)({
        selection: null,
        range: null,
        text: "",
    });
    const scrolledToHighlightIdRef = (0, react_1.useRef)(null); // Reference to the ID of the highlight autoscrolled to
    const isAreaSelectionInProgressRef = (0, react_1.useRef)(false);
    const isEditInProgressRef = (0, react_1.useRef)(false);
    const [tip, setTip] = (0, react_1.useState)(null);
    const [isViewerReady, setIsViewerReady] = (0, react_1.useState)(false);
    // These should only change when a document loads/unloads
    const eventBusRef = (0, react_1.useRef)(new pdf_viewer_1.EventBus());
    const linkServiceRef = (0, react_1.useRef)(new pdf_viewer_1.PDFLinkService({
        eventBus: eventBusRef.current,
        externalLinkTarget: 2,
    }));
    const resizeObserverRef = (0, react_1.useRef)(null);
    const viewerRef = (0, react_1.useRef)(null);
    const findOrCreateHighlightLayer = (textLayer) => {
        return (0, pdfjs_dom_1.findOrCreateContainerLayer)(textLayer, "PdfHighlighter__highlight-layer");
    };
    // Init listeners
    (0, react_1.useLayoutEffect)(() => {
        resizeObserverRef.current = new ResizeObserver(handleScaleValue);
        const doc = containerNodeRef.current?.ownerDocument;
        if (!doc || !containerNodeRef.current)
            return;
        resizeObserverRef.current.observe(containerNodeRef.current);
        eventBusRef.current.on("textlayerrendered", renderHighlightLayers);
        eventBusRef.current.on("pagesinit", handleScaleValue);
        doc.addEventListener("selectionchange", handleSelectionChange);
        doc.addEventListener("keydown", handleKeyDown);
        renderHighlightLayers();
        return () => {
            eventBusRef.current.off("pagesinit", handleScaleValue);
            eventBusRef.current.off("textlayerrendered", renderHighlightLayers);
            doc.removeEventListener("selectionchange", handleSelectionChange);
            doc.removeEventListener("keydown", handleKeyDown);
            resizeObserverRef.current?.disconnect();
        };
    }, [selectionTip, highlights, onSelectionFinished]);
    // Initialise PDF Viewer
    (0, react_1.useLayoutEffect)(() => {
        const doc = containerNodeRef.current?.ownerDocument;
        if (!doc || !containerNodeRef.current)
            return;
        viewerRef.current =
            viewerRef.current ||
                new pdf_viewer_1.PDFViewer({
                    container: containerNodeRef.current,
                    eventBus: eventBusRef.current,
                    textLayerMode: 2, // Needed to prevent flickering in Chrome. Known issue with PDF.js
                    removePageBorders: true,
                    linkService: linkServiceRef.current,
                    l10n: pdf_viewer_1.NullL10n, // No localisation
                });
        linkServiceRef.current.setDocument(pdfDocument);
        linkServiceRef.current.setViewer(viewerRef.current);
        viewerRef.current.setDocument(pdfDocument);
        setIsViewerReady(true);
    }, []);
    const isTextSelectionEmpty = () => {
        return (!textSelectionRef.current ||
            textSelectionRef.current.selection?.isCollapsed ||
            !textSelectionRef.current.range ||
            !textSelectionRef.current.text);
    };
    const isSelectionInProgress = () => {
        return (!isTextSelectionEmpty() ||
            Boolean(ghostHighlightRef.current) ||
            isAreaSelectionInProgressRef.current ||
            isEditInProgressRef.current);
    };
    const removeGhostHighlight = () => {
        ghostHighlightRef.current = null;
        renderHighlightLayers();
    };
    const scrollTo = (highlight) => {
        const { boundingRect, usePdfCoordinates } = highlight.position;
        const pageNumber = boundingRect.pageNumber;
        // Remove scroll listener in case user auto-scrolls in succession.
        onScrollAway &&
            viewerRef.current.container.removeEventListener("scroll", handleScroll);
        const pageViewport = viewerRef.current.getPageView(pageNumber - 1).viewport;
        viewerRef.current.scrollPageIntoView({
            pageNumber,
            destArray: [
                null, // null since we pass pageNumber already as an arg
                { name: "XYZ" },
                ...pageViewport.convertToPdfPoint(0, // Default x coord
                (0, coordinates_1.scaledToViewport)(boundingRect, pageViewport, usePdfCoordinates).top -
                    SCROLL_MARGIN),
                0, // Default z coord
            ],
        });
        scrolledToHighlightIdRef.current = highlight.id;
        renderHighlightLayers();
        // wait for scrolling to finish
        setTimeout(() => {
            onScrollAway &&
                viewerRef.current.container.addEventListener("scroll", handleScroll, {
                    once: true,
                });
        }, 100);
    };
    const handleScroll = () => {
        onScrollAway();
        scrolledToHighlightIdRef.current = null;
        renderHighlightLayers();
    };
    const handleSelectionChange = () => {
        const container = containerNodeRef.current;
        const selection = (0, pdfjs_dom_1.getWindow)(container).getSelection();
        if (!container || !selection || selection.isCollapsed)
            return;
        const range = selection.rangeCount > 0 ? selection.getRangeAt(0) : null;
        if (!range ||
            !container.contains(range.commonAncestorContainer) // Check the selected text is in the document, not the tip
        ) {
            return;
        }
        textSelectionRef.current = {
            selection,
            range,
            text: selection.toString().split("\n").join(" "), // Make all line breaks spaces
        };
        debouncedHandleAfterSelection();
    };
    const handleAfterSelection = () => {
        const { selection, range, text } = textSelectionRef.current;
        if (!range || selection?.isCollapsed) {
            return;
        }
        const pages = (0, pdfjs_dom_1.getPagesFromRange)(range);
        if (!pages || pages.length === 0) {
            return;
        }
        const rects = (0, get_client_rects_1.default)(range, pages);
        if (rects.length === 0) {
            return;
        }
        const boundingRect = (0, get_bounding_rect_1.default)(rects);
        const viewportPosition = {
            boundingRect,
            rects,
        };
        const content = { text };
        const scaledPosition = (0, coordinates_1.viewportPositionToScaled)(viewportPosition, viewerRef.current);
        const selectionUtils = {
            selectionPosition: scaledPosition,
            selectionContent: content,
            removeGhostHighlight,
            makeGhostHighlight: () => {
                ghostHighlightRef.current = {
                    content: content,
                    position: scaledPosition,
                };
                renderHighlightLayers();
            },
        };
        if (onSelectionFinished)
            onSelectionFinished(selectionUtils);
        if (selectionTip) {
            const newTip = {
                position: viewportPosition,
                content: (react_1.default.createElement(SelectionContext_1.SelectionContext.Provider, { value: selectionUtils }, selectionTip)),
            };
            setTip(newTip);
        }
    };
    const debouncedHandleAfterSelection = (0, lodash_debounce_1.default)(handleAfterSelection, TIP_WAIT);
    const handleMouseDown = (event) => {
        if (!(0, pdfjs_dom_1.isHTMLElement)(event.target) ||
            (0, pdfjs_dom_1.asElement)(event.target).closest(".PdfHighlighter__tip-container") // Ignore selections on tip container
        ) {
            return;
        }
        setTip(null);
        removeGhostHighlight();
    };
    const handleKeyDown = (event) => {
        if (event.code === "Escape") {
            removeGhostHighlight();
            setTip(null);
        }
    };
    const handleScaleValue = () => {
        if (viewerRef.current) {
            viewerRef.current.currentScaleValue = pdfScaleValue.toString();
        }
    };
    const renderHighlightLayers = () => {
        if (!viewerRef.current)
            return;
        for (let pageNumber = 1; pageNumber <= pdfDocument.numPages; pageNumber++) {
            const highlightBindings = highlightBindingsRef.current[pageNumber];
            // Need to check if container is still attached to the DOM as PDF.js can unload pages.
            if (highlightBindings?.container?.isConnected) {
                renderHighlightLayer(highlightBindings, pageNumber);
            }
            else {
                const { textLayer } = viewerRef.current.getPageView(pageNumber - 1) || {};
                if (!textLayer)
                    continue; // Viewer hasn't rendered page yet
                const highlightLayer = findOrCreateHighlightLayer(textLayer.div);
                if (highlightLayer) {
                    const reactRoot = (0, client_1.createRoot)(highlightLayer);
                    highlightBindingsRef.current[pageNumber] = {
                        reactRoot,
                        container: highlightLayer,
                        textLayer: textLayer.div,
                    };
                    renderHighlightLayer(highlightBindingsRef.current[pageNumber], pageNumber);
                }
            }
        }
    };
    const renderHighlightLayer = (highlightBindings, pageNumber) => {
        if (!viewerRef.current)
            return;
        highlightBindings.reactRoot.render(react_1.default.createElement(TipContext_1.TipViewerContext.Provider, { value: tipViewerUtils },
            react_1.default.createElement(HighlightLayer_1.default, { highlightsByPage: (0, group_highlights_by_page_1.default)([
                    ...highlights,
                    ghostHighlightRef.current,
                ]), pageNumber: pageNumber, isSelectionInProgress: isSelectionInProgress, scrolledToHighlightId: scrolledToHighlightIdRef.current, viewer: viewerRef.current, highlightBindings: highlightBindings, children: children })));
    };
    const tipViewerUtils = {
        currentTip: tip,
        setTip: (tip) => setTip(tip),
        toggleEditInProgress: (flag) => {
            if (flag !== undefined) {
                isEditInProgressRef.current = flag;
            }
            else {
                isEditInProgressRef.current = !isEditInProgressRef.current;
            }
            (0, disable_text_selection_1.disableTextSelection)(viewerRef.current, isEditInProgressRef.current);
        },
        isEditInProgress: () => isEditInProgressRef.current,
    };
    scrollRef && scrollRef(scrollTo);
    tipViewerUtilsRef && tipViewerUtilsRef(tipViewerUtils);
    pdfViewerRef && viewerRef.current && pdfViewerRef(viewerRef.current);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("div", { ref: containerNodeRef, className: "PdfHighlighter", onPointerDown: handleMouseDown, style: style },
            react_1.default.createElement("div", { className: "pdfViewer" }),
            react_1.default.createElement("style", null, `
          .textLayer ::selection {
            background: ${textSelectionColor};
          }
        `),
            react_1.default.createElement(TipContext_1.TipViewerContext.Provider, { value: tipViewerUtils },
                isViewerReady && react_1.default.createElement(TipRenderer_1.default, { viewer: viewerRef.current }),
                isViewerReady && enableAreaSelection && (react_1.default.createElement(MouseSelectionRenderer_1.default, { viewer: viewerRef.current, onChange: (isVisible) => (isAreaSelectionInProgressRef.current = isVisible), enableAreaSelection: enableAreaSelection, style: mouseSelectionStyle, onAfterSelection: (viewportPosition, scaledPosition, image, resetSelection) => {
                        const selectionUtils = {
                            selectionPosition: scaledPosition,
                            selectionContent: { image },
                            removeGhostHighlight,
                            makeGhostHighlight: () => {
                                ghostHighlightRef.current = {
                                    position: scaledPosition,
                                    content: { image },
                                };
                                resetSelection();
                                renderHighlightLayers();
                            },
                        };
                        onSelectionFinished && onSelectionFinished(selectionUtils);
                        if (selectionTip) {
                            const newTip = {
                                position: viewportPosition,
                                content: (react_1.default.createElement(SelectionContext_1.SelectionContext.Provider, { value: selectionUtils }, selectionTip)),
                            };
                            setTip(newTip);
                        }
                    } }))))));
};
exports.default = PdfHighlighter;
//# sourceMappingURL=PdfHighlighter.js.map