"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const TipContext_1 = require("../contexts/TipContext");
const clamp = (value, left, right) => Math.min(Math.max(value, left), right);
const VERTICAL_PADDING = 5;
/**
 * A component that manages rendering and placement of a tip around a highlight.
 * It also provides the ability for children to update the position of the container
 * via context.
 */
const TipContainer = ({ children, position, scrollTop, pageBoundingRect, }) => {
    const [height, setHeight] = (0, react_1.useState)(0);
    const [width, setWidth] = (0, react_1.useState)(0);
    const nodeRef = (0, react_1.useRef)(null);
    const updatePosition = () => {
        if (!nodeRef.current)
            return;
        const { offsetHeight, offsetWidth } = nodeRef.current;
        setHeight(offsetHeight);
        setWidth(offsetWidth);
    };
    (0, react_1.useLayoutEffect)(() => {
        updatePosition();
    }, []);
    const shouldMove = position.highlightTop - height - VERTICAL_PADDING < scrollTop; // should move below highlight?
    const top = shouldMove
        ? position.highlightBottom + 5
        : position.highlightTop - height - 5;
    // Forces tip to stay within the left edge of the pdf viewer componenet
    // and the right edge of the page. Not a perfect clamp, but functional enough.
    const left = clamp(position.left - width / 2, 0, pageBoundingRect.left + pageBoundingRect.width - width);
    return (react_1.default.createElement(TipContext_1.TipContainerContext.Provider, { value: { updatePosition } },
        react_1.default.createElement("div", { className: "PdfHighlighter__tip-container", style: {
                top,
                left,
                height: "max-content",
                width: "max-content",
            }, ref: nodeRef }, children)));
};
exports.default = TipContainer;
//# sourceMappingURL=TipContainer.js.map