/// <reference types="react" />
import { Tip } from "../types";
/**
 * A set of utilities for displaying a tip inside of a PdfHighlighter component.
 */
export type TipViewerUtils = {
    /**
     * The current tip displayed in the viewer
     */
    currentTip: Tip | null;
    /**
     * Set a tip manually to be displayed in the PDF viewer or
     * set to `null` to hide any existing tip.
     */
    setTip: (tip: Tip | null) => void;
    /**
     * If enabled, automatic tips/popups inside of a PdfHighlighter will be disabled.
     * Additional niceties will also be provided to prevent new highlights being made.
     */
    toggleEditInProgress: (flag?: boolean) => void;
    /**
     * Whether an AreaHighlight is being moved/resized, or a manual highlight edit has
     * been toggled.
     */
    isEditInProgress: () => boolean;
};
/**
 * A set of utilities to be used inside a tip displayed within a PdfHighlighter component.
 */
export type TipContainerUtils = {
    /**
     * Recorrect a tip's position to account for its size.
     * Useful if your tip resizes at any point.
     */
    updatePosition: () => void;
};
export declare const TipViewerContext: import("react").Context<TipViewerUtils | undefined>;
export declare const TipContainerContext: import("react").Context<TipContainerUtils | undefined>;
export declare const useTipViewerUtils: () => TipViewerUtils;
export declare const useTipContainerUtils: () => TipContainerUtils;
