"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const groupHighlightsByPage = (highlights) => {
    const allHighlights = highlights.filter(Boolean);
    const groupedHighlights = {};
    allHighlights.forEach((highlight) => {
        const pageNumbers = new Set();
        pageNumbers.add(highlight.position.boundingRect.pageNumber);
        // Add page numbers of all associated rects
        // to deal with multi-page highlights
        highlight.position.rects.forEach((rect) => {
            if (rect.pageNumber) {
                pageNumbers.add(rect.pageNumber);
            }
        });
        // Push the highlight and right rects to all relevant pages
        pageNumbers.forEach((pageNumber) => {
            if (!groupedHighlights[pageNumber]) {
                groupedHighlights[pageNumber] = [];
            }
            const pageSpecificHighlight = {
                ...highlight,
                position: {
                    ...highlight.position,
                    rects: highlight.position.rects.filter((rect) => pageNumber === rect.pageNumber),
                },
            };
            groupedHighlights[pageNumber].push(pageSpecificHighlight);
        });
    });
    return groupedHighlights;
};
exports.default = groupHighlightsByPage;
//# sourceMappingURL=group-highlights-by-page.js.map