import React from "react";
import { HighlightContext } from "../contexts/HighlightContext";
import { scaledPositionToViewport, viewportToScaled } from "../lib/coordinates";
import screenshot from "../lib/screenshot";
const EMPTY_ID = "empty-id";
/**
 * An internal component that holds all the highlights and ghost highlights
 * for a single page of a PDF document.
 * It should be given a HighlightContainer as a child and all children will be wrapped
 * in the correct HighlightContext. Its rendering should be managed by the PdfHighlighter.
 */
const HighlightLayer = ({ highlightsByPage, pageNumber, scrolledToHighlightId, viewer, isSelectionInProgress, highlightBindings, children, }) => {
    const currentHighlights = highlightsByPage[pageNumber] || [];
    return (React.createElement("div", null, currentHighlights.map((highlight, index) => {
        const viewportHighlight = {
            ...highlight,
            id: "id" in highlight ? highlight.id : EMPTY_ID, // Give Empty ID to GhostHighlight
            comment: "comment" in highlight ? highlight.comment : { text: "" }, // Give empty comment to GhostHighlight
            position: scaledPositionToViewport(highlight.position, viewer),
        };
        const isScrolledTo = Boolean(scrolledToHighlightId === viewportHighlight.id);
        const highlightUtils = {
            highlight: viewportHighlight,
            key: index,
            isSelectionInProgress,
            viewportToScaled: (rect) => {
                const viewport = viewer.getPageView((rect.pageNumber || pageNumber) - 1 // Convert to 0 index
                ).viewport;
                return viewportToScaled(rect, viewport);
            },
            screenshot: (boundingRect) => screenshot(boundingRect, pageNumber, viewer),
            isScrolledTo: isScrolledTo,
            highlightBindings,
        };
        return (React.createElement(HighlightContext.Provider, { value: highlightUtils, key: index }, children));
    })));
};
export default HighlightLayer;
//# sourceMappingURL=HighlightLayer.js.map