import React, { useRef } from "react";
import MouseMonitor from "./MouseMonitor";
/**
 * A container for a highlight component that monitors whether a mouse is over a highlight
 * and over some secondary/popup content. This does not render any popup/tip,
 * but it should ideally be used to set the visible state / rendering of a popup.
 */
const MonitoredHighlightContainer = ({ onMouseOver, popupContent, onMouseOut, children, }) => {
    const mouseInRef = useRef(false); // Whether the mouse is over the child (highlight)
    // Create a mouse monitor for the popup content
    const monitorContent = (React.createElement(MouseMonitor, { onMoveAway: () => {
            if (mouseInRef.current) {
                return;
            }
            onMouseOut();
        }, paddingX: 60, paddingY: 30 }, popupContent));
    return (React.createElement("div", { onMouseEnter: () => {
            mouseInRef.current = true;
            onMouseOver(monitorContent);
        }, onMouseLeave: () => {
            mouseInRef.current = false;
        } }, children));
};
export default MonitoredHighlightContainer;
//# sourceMappingURL=MonitoredHighlightContainer.js.map