import { PDFViewer } from "pdfjs-dist/types/web/pdf_rendering_queue";
import React, { CSSProperties } from "react";
import { ScaledPosition, ViewportPosition } from "src/types";
interface MouseSelectionRendererProps {
    viewer: PDFViewer;
    /** Callback passed to MouseSelection. See doc there. */
    onChange: (isVisible: boolean) => void;
    /**
     * Callback after a valid mouse selection has been made inside of a PdfHighlighter.
     *
     * @param viewportPosition - ViewportPosition of selection.
     * @param scaledPosition - ScaledPosition of selection.
     * @param image - PNG data url of a screenshot of the mouse selection.
     * @param resetSelection - Callback to reset current selection. See MouseSelection.
     */
    onAfterSelection: (viewportPosition: ViewportPosition, scaledPosition: ScaledPosition, image: string, resetSelection: () => void) => void;
    /**
     * Function to determine whether MouseSelection should start based on the initial click event.
     * Checks for whether the click occurred inside the PdfHighlighter and on a valid element are already made.
     * This should be used strictly for any conditionals to area selection.
     *
     * @param event - The mouse event.
     */
    enableAreaSelection: (event: MouseEvent) => boolean;
    style?: CSSProperties;
}
/**
 * A helper component that defines and processes the right props to setup a MouseSelection
 * component inside of a PdfHighlighter component. Its existence is highly dependent on a
 * PdfHighlighter, but it is independently written to help declutter the PdfHighlighter.
 */
declare const MouseSelectionRenderer: ({ viewer, onChange, onAfterSelection, enableAreaSelection, style, }: MouseSelectionRendererProps) => React.JSX.Element;
export default MouseSelectionRenderer;
