import React from "react";
import { viewportPositionToScaled } from "../lib/coordinates";
import { asElement, getPageFromElement, isHTMLElement } from "../lib/pdfjs-dom";
import screenshot from "../lib/screenshot";
import MouseSelection from "./MouseSelection";
import { disableTextSelection } from "../lib/disable-text-selection";
/**
 * A helper component that defines and processes the right props to setup a MouseSelection
 * component inside of a PdfHighlighter component. Its existence is highly dependent on a
 * PdfHighlighter, but it is independently written to help declutter the PdfHighlighter.
 */
const MouseSelectionRenderer = ({ viewer, onChange, onAfterSelection, enableAreaSelection, style, }) => {
    const handleSelection = (startTarget, boundingRect, resetSelection) => {
        const page = getPageFromElement(startTarget);
        if (!page)
            return;
        const pageBoundingRect = {
            ...boundingRect,
            top: boundingRect.top - page.node.offsetTop,
            left: boundingRect.left - page.node.offsetLeft,
            pageNumber: page.number,
        };
        const viewportPosition = {
            boundingRect: pageBoundingRect,
            rects: [],
        };
        const scaledPosition = viewportPositionToScaled(viewportPosition, viewer);
        const image = screenshot(pageBoundingRect, pageBoundingRect.pageNumber, viewer);
        onAfterSelection(viewportPosition, scaledPosition, image, resetSelection);
    };
    return (React.createElement(MouseSelection, { onDragStart: () => disableTextSelection(viewer, true), onDragEnd: () => disableTextSelection(viewer, false), onChange: onChange, shouldStart: (event) => enableAreaSelection(event) &&
            isHTMLElement(event.target) &&
            Boolean(asElement(event.target).closest(".page")), onSelection: handleSelection, style: style }));
};
export default MouseSelectionRenderer;
//# sourceMappingURL=MouseSelectionRenderer.js.map