import React, { useEffect, useState } from "react";
import { GlobalWorkerOptions, getDocument } from "pdfjs-dist/legacy/build/pdf";
import { PdfLoaderContext } from "../contexts/PdfLoaderContext";
const DEFAULT_BEFORE_LOAD = (progress) => (React.createElement("div", { style: { color: "black" } },
    "Loading ",
    Math.floor((progress.loaded / progress.total) * 100),
    "%"));
const DEFAULT_ERROR_MESSAGE = (React.createElement("div", { style: { color: "black" } }, "Oh no! An error has occurred."));
const DEFAULT_ON_ERROR = (error) => {
    throw new Error(`Error loading PDF document: ${error.message}!`);
};
const DEFAULT_WORKER_SRC = "https://unpkg.com/pdfjs-dist@3.8.162/build/pdf.worker.min.js";
/**
 * A component for loading a PDF document and passing it to a child.
 */
const PdfLoader = ({ document, beforeLoad = DEFAULT_BEFORE_LOAD, errorMessage = DEFAULT_ERROR_MESSAGE, children, onError = DEFAULT_ON_ERROR, workerSrc = DEFAULT_WORKER_SRC, }) => {
    const [pdfDocument, setPdfDocument] = useState(null);
    const [error, setError] = useState(null);
    const [loadingProgress, setLoadingProgress] = useState(null);
    // Intitialise document
    useEffect(() => {
        GlobalWorkerOptions.workerSrc = workerSrc;
        const pdfLoadingTask = getDocument(document);
        pdfLoadingTask.promise
            .then((pdfDocument) => {
            setPdfDocument(pdfDocument);
        })
            .catch((error) => {
            setError(error);
            onError(error);
        })
            .finally(() => {
            setLoadingProgress(null);
        });
        pdfLoadingTask.onProgress = (progress) => {
            setLoadingProgress(progress);
        };
        return () => {
            if (pdfDocument) {
                pdfDocument.destroy();
            }
        };
    }, [document]);
    return error
        ? errorMessage
        : loadingProgress
            ? beforeLoad(loadingProgress)
            : pdfDocument && (React.createElement(PdfLoaderContext.Provider, { value: pdfDocument, children: children }));
};
export default PdfLoader;
//# sourceMappingURL=PdfLoader.js.map