import React, { ReactNode } from "react";
import type { LTWHP } from "../types";
type TipPosition = {
    /** Distance from the top of the viewport to the top of a highlight */
    highlightTop: number;
    /** Distance from the top of the viewport to the bottom of a highlight */
    highlightBottom: number;
    /**
     * Distance from the left edge of the container to the
     * middle of the tip (i.e., middle of a highlight)
     */
    left: number;
};
interface TipContainerProps {
    children: ReactNode;
    position: TipPosition;
    /**
     * How much the container's content has been scrolled vertically. Pass the scrollTop of
     * the PDF.js viewer's container.
     */
    scrollTop: number;
    pageBoundingRect: LTWHP;
}
/**
 * A component that manages rendering and placement of a tip around a highlight.
 * It also provides the ability for children to update the position of the container
 * via context.
 */
declare const TipContainer: ({ children, position, scrollTop, pageBoundingRect, }: TipContainerProps) => React.JSX.Element;
export default TipContainer;
