import React, { useLayoutEffect, useRef, useState } from "react";
import { TipContainerContext } from "../contexts/TipContext";
const clamp = (value, left, right) => Math.min(Math.max(value, left), right);
const VERTICAL_PADDING = 5;
/**
 * A component that manages rendering and placement of a tip around a highlight.
 * It also provides the ability for children to update the position of the container
 * via context.
 */
const TipContainer = ({ children, position, scrollTop, pageBoundingRect, }) => {
    const [height, setHeight] = useState(0);
    const [width, setWidth] = useState(0);
    const nodeRef = useRef(null);
    const updatePosition = () => {
        if (!nodeRef.current)
            return;
        const { offsetHeight, offsetWidth } = nodeRef.current;
        setHeight(offsetHeight);
        setWidth(offsetWidth);
    };
    useLayoutEffect(() => {
        updatePosition();
    }, []);
    const shouldMove = position.highlightTop - height - VERTICAL_PADDING < scrollTop; // should move below highlight?
    const top = shouldMove
        ? position.highlightBottom + 5
        : position.highlightTop - height - 5;
    // Forces tip to stay within the left edge of the pdf viewer componenet
    // and the right edge of the page. Not a perfect clamp, but functional enough.
    const left = clamp(position.left - width / 2, 0, pageBoundingRect.left + pageBoundingRect.width - width);
    return (React.createElement(TipContainerContext.Provider, { value: { updatePosition } },
        React.createElement("div", { className: "PdfHighlighter__tip-container", style: {
                top,
                left,
                height: "max-content",
                width: "max-content",
            }, ref: nodeRef }, children)));
};
export default TipContainer;
//# sourceMappingURL=TipContainer.js.map